@@ -17,6 +17,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -48,6 +53,7 @@ __all__ = ["LOGGER",
 		"unpackDefault",
 		"orderedUniqify",
 		"pathExists",
+		"filterPath",
 		"getFirstItem",
 		"getLastItem",
 		"isBinaryFile",
@@ -112,6 +118,16 @@ def pathExists(path):
 	else:
 		return os.path.exists(path)
 
+def filterPath(path):
+	"""
+	This definition filters given path.
+
+	:param path: Path. ( String )
+	:return: Filtered path. ( String )
+	"""
+
+	return path if pathExists(path) else ""
+
 def getFirstItem(iterable, default=None):
 	"""
 	This definition returns the first item of given iterable.
@@ -154,7 +170,7 @@ def isBinaryFile(file):
 		chunkSize = 1024
 		while True:
 			chunk = fileHandle.read(chunkSize)
-			if "\0" in chunk:
+			if chr(0) in chunk:
 				return True
 			if len(chunk) < chunkSize:
 				break
@@ -215,6 +231,6 @@ def getHostAddress(host=None, defaultAddress=DEFAULT_HOST_IP):
 	"""
 
 	try:
-		return socket.gethostbyname(host or socket.gethostname())
+		return unicode(socket.gethostbyname(host or socket.gethostname()))
 	except Exception as error:
 		return defaultAddress
