@@ -15,6 +15,11 @@
 	Portions of the code from Fredrik Lundh: http://effbot.org/zone/element-iterparse.htm
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -116,7 +121,7 @@ class SectionsFileParser(foundations.io.File):
 				commentLimiters=(";", "#"),
 				commentMarker="#",
 				quotationMarkers=("\"", "'", "`"),
-				rawSectionContentIdentifier="_rawSectionContent",
+				rawSectionContentIdentifier="__raw__",
 				defaultsSection="_defaults"):
 		"""
 		This method initializes the class.
@@ -130,9 +135,9 @@ class SectionsFileParser(foundations.io.File):
 			>>> sectionsFileParser.parse(stripComments=False)
 			True
 			>>> sectionsFileParser.sections.keys()
-			['Section A', 'Section B']
+			[u'Section A', u'Section B']
 			>>> sectionsFileParser.comments 
-			OrderedDict([('Section A|#0', {'content': 'Comment.', 'id': 0})])
+			OrderedDict([(u'Section A|#0', {u'content': u'Comment.', u'id': 0})])
 
 		:param file: Current file path. ( String )
 		:param splitters: Splitter characters.  ( Tuple / List )
@@ -159,7 +164,7 @@ class SectionsFileParser(foundations.io.File):
 		self.commentMarker = commentMarker
 		self.__quotationMarkers = None
 		self.quotationMarkers = quotationMarkers
-		self.__rawSectionContentIdentifier = None
+		self.___raw__Identifier = None
 		self.rawSectionContentIdentifier = rawSectionContentIdentifier
 		self.__defaultsSection = None
 		self.defaultsSection = defaultsSection
@@ -194,7 +199,7 @@ class SectionsFileParser(foundations.io.File):
 			assert type(value) in (tuple, list), "'{0}' attribute: '{1}' type is not 'tuple' or 'list'!".format(
 			"splitters", value)
 			for element in value:
-				assert type(element) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+				assert type(element) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 				"splitters", element)
 				assert len(element) == 1, "'{0}' attribute: '{1}' has multiples characters!".format("splitter", element)
 				assert not re.search(r"\w", element), "'{0}' attribute: '{1}' is an alphanumeric character!".format(
@@ -231,7 +236,7 @@ class SectionsFileParser(foundations.io.File):
 		"""
 
 		if value is not None:
-			assert type(value) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+			assert type(value) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 			"namespaceSplitter", value)
 			assert len(value) == 1, "'{0}' attribute: '{1}' has multiples characters!".format("namespaceSplitter", value)
 			assert not re.search(r"\w", value), "'{0}' attribute: '{1}' is an alphanumeric character!".format(
@@ -271,7 +276,7 @@ class SectionsFileParser(foundations.io.File):
 			assert type(value) in (tuple, list), "'{0}' attribute: '{1}' type is not 'tuple' or 'list'!".format(
 			"commentLimiters", value)
 			for element in value:
-				assert type(element) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+				assert type(element) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 				"commentLimiters", element)
 		self.__commentLimiters = value
 
@@ -305,7 +310,7 @@ class SectionsFileParser(foundations.io.File):
 		"""
 
 		if value is not None:
-			assert type(value) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+			assert type(value) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 			"commentMarker", value)
 			assert not re.search(r"\w", value), "'{0}' attribute: '{1}' is an alphanumeric character!".format(
 			"commentMarker", value)
@@ -344,7 +349,7 @@ class SectionsFileParser(foundations.io.File):
 			assert type(value) in (tuple, list), "'{0}' attribute: '{1}' type is not 'tuple' or 'list'!".format(
 			"quotationMarkers", value)
 			for element in value:
-				assert type(element) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+				assert type(element) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 				"quotationMarkers", element)
 				assert len(element) == 1, "'{0}' attribute: '{1}' has multiples characters!".format("quotationMarkers",
 				 																					element)
@@ -365,32 +370,32 @@ class SectionsFileParser(foundations.io.File):
 	@property
 	def rawSectionContentIdentifier(self):
 		"""
-		This method is the property for **self.__rawSectionContentIdentifier** attribute.
+		This method is the property for **self.___raw__Identifier** attribute.
 
-		:return: self.__rawSectionContentIdentifier. ( String )
+		:return: self.___raw__Identifier. ( String )
 		"""
 
-		return self.__rawSectionContentIdentifier
+		return self.___raw__Identifier
 
 	@rawSectionContentIdentifier.setter
 	@foundations.exceptions.handleExceptions(AssertionError)
 	def rawSectionContentIdentifier(self, value):
 		"""
-		This method is the setter method for **self.__rawSectionContentIdentifier** attribute.
+		This method is the setter method for **self.___raw__Identifier** attribute.
 
 		:param value: Attribute value. ( String )
 		"""
 
 		if value is not None:
-			assert type(value) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+			assert type(value) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 			"rawSectionContentIdentifier", value)
-		self.__rawSectionContentIdentifier = value
+		self.___raw__Identifier = value
 
 	@rawSectionContentIdentifier.deleter
 	@foundations.exceptions.handleExceptions(foundations.exceptions.ProgrammingError)
 	def rawSectionContentIdentifier(self):
 		"""
-		This method is the deleter method for **self.__rawSectionContentIdentifier** attribute.
+		This method is the deleter method for **self.___raw__Identifier** attribute.
 		"""
 
 		raise foundations.exceptions.ProgrammingError(
@@ -416,7 +421,7 @@ class SectionsFileParser(foundations.io.File):
 		"""
 
 		if value is not None:
-			assert type(value) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+			assert type(value) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 			"defaultsSection", value)
 		self.__defaultsSection = value
 
@@ -453,7 +458,7 @@ class SectionsFileParser(foundations.io.File):
 			assert type(value) in (OrderedDict, dict), "'{0}' attribute: '{1}' type is not \
 			'OrderedDict' or 'dict'!".format("sections", value)
 			for key, element in value.iteritems():
-				assert type(key) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+				assert type(key) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 				"sections", key)
 				assert type(element) in (OrderedDict, dict), "'{0}' attribute: '{1}' type is not \
 				'OrderedDict' or 'dict'!".format("sections", key)
@@ -492,7 +497,7 @@ class SectionsFileParser(foundations.io.File):
 			assert type(value) in (OrderedDict, dict), "'{0}' attribute: '{1}' type is not \
 			'OrderedDict' or 'dict'!".format("comments", value)
 			for key, element in value.iteritems():
-				assert type(key) in (str, unicode), "'{0}' attribute: '{1}' type is not 'str' or 'unicode'!".format(
+				assert type(key) is unicode, "'{0}' attribute: '{1}' type is not 'unicode'!".format(
 				"comments", key)
 				assert type(element) in (OrderedDict, dict), "'{0}' attribute: '{1}' type is not \
 				'OrderedDict' or 'dict'!".format("comments", key)
@@ -569,21 +574,23 @@ class SectionsFileParser(foundations.io.File):
 			>>> sectionsFileParser.parse(stripComments=False)
 			True
 			>>> sectionsFileParser.sections.keys()
-			['_defaults']
+			[u'_defaults']
 			>>> sectionsFileParser.sections["_defaults"].values()
-			['Value A', 'Value B']
-			>>> sectionsFileParser.parse(stripQuotationMarkers=False)
+			[u'Value A', u'Value B']
+			>>> sectionsFileParser.parse(stripComments=False, stripQuotationMarkers=False)
 			True
 			>>> sectionsFileParser.sections["_defaults"].values()
-			['"Value A"', '"Value B"']
+			[u'"Value A"', u'"Value B"']
 			>>> sectionsFileParser.comments 
-			OrderedDict([('_defaults|#0', {'content': 'Comment.', 'id': 0})])
+			OrderedDict([(u'_defaults|#0', {u'content': u'Comment.', u'id': 0})])
 			>>> sectionsFileParser.parse()
 			True
 			>>> sectionsFileParser.sections["_defaults"]
-			OrderedDict([('_defaults|Attribute 1', 'Value A'), ('_defaults|Attribute 2', 'Value B')])
+			OrderedDict([(u'_defaults|Attribute 1', u'Value A'), (u'_defaults|Attribute 2', u'Value B')])
 			>>> sectionsFileParser.parse(namespaces=False)
-			OrderedDict([('Attribute 1', 'Value A'), ('Attribute 2', 'Value B')])
+			True
+			>>> sectionsFileParser.sections["_defaults"]
+			OrderedDict([(u'Attribute 1', u'Value A'), (u'Attribute 2', u'Value B')])
 
 		:param orderedDictionary: SectionsFileParser data is stored
 			in :class:`collections.OrderedDict` dictionaries. ( Boolean )
@@ -640,7 +647,7 @@ class SectionsFileParser(foundations.io.File):
 
 			if section in rawSections:
 				rawContent.append(line)
-				attributes[self.__rawSectionContentIdentifier] = rawContent
+				attributes[self.___raw__Identifier] = rawContent
 			else:
 				# Empty line matching.
 				search = re.search(r"^\s*$", line)
@@ -749,11 +756,11 @@ class SectionsFileParser(foundations.io.File):
 			>>> sectionsFileParser.parse()
 			True
 			>>> sectionsFileParser.getAttributes("Section A")
-			OrderedDict([('Section A|Attribute 1', 'Value A')])
+			OrderedDict([(u'Section A|Attribute 1', u'Value A')])
 			>>> sectionsFileParser.getAttributes("Section A", orderedDictionary=False)
-			{'Section A|Attribute 1': 'Value A'}
+			{u'Section A|Attribute 1': u'Value A'}
 			>>> sectionsFileParser.getAttributes("Section A", stripNamespaces=True)
-			OrderedDict([('Attribute 1', 'Value A')])
+			OrderedDict([(u'Attribute 1', u'Value A')])
 
 		:param section: Section containing the requested attributes. ( String )
 		:param orderedDictionary: Use an :class:`collections.OrderedDict` dictionary to store the attributes. ( String )
@@ -788,9 +795,9 @@ class SectionsFileParser(foundations.io.File):
 			>>> sectionsFileParser.parse()
 			True
 			>>> sectionsFileParser.getAllAttributes()
-			OrderedDict([('Section A|Attribute 1', 'Value A'), ('Section B|Attribute 2', 'Value B')])
+			OrderedDict([(u'Section A|Attribute 1', u'Value A'), (u'Section B|Attribute 2', u'Value B')])
 			>>> sectionsFileParser.getAllAttributes(orderedDictionary=False)
-			{'Section B|Attribute 2': 'Value B', 'Section A|Attribute 1': 'Value A'}
+			{u'Section B|Attribute 2': u'Value B', u'Section A|Attribute 1': u'Value A'}
 
 		:param orderedDictionary: Use an :class:`collections.OrderedDict` dictionary to store the attributes. ( String )
 		:return: All sections / files attributes. ( OrderedDict / Dictionary )
@@ -806,7 +813,7 @@ class SectionsFileParser(foundations.io.File):
 				allAttributes[attribute] = value
 		return allAttributes
 
-	def getValue(self, attribute, section, encode=False, default=str()):
+	def getValue(self, attribute, section, default=""):
 		"""
 		This method returns requested attribute value.
 
@@ -819,11 +826,10 @@ class SectionsFileParser(foundations.io.File):
 			>>> sectionsFileParser.parse()
 			True
 			>>> sectionsFileParser.getValue("Attribute 1", "Section A")
-			Value A
+			u'Value A'
 
 		:param attribute: Attribute name. ( String )
 		:param section: Section containing the searched attribute. ( String )
-		:param encode: Encode value to unicode. ( Boolean )
 		:param default: Default return value. ( Object )
 		:return: Attribute value. ( String )
 		"""
@@ -839,7 +845,6 @@ class SectionsFileParser(foundations.io.File):
 		elif foundations.namespace.setNamespace(section, attribute) in self.__sections[section]:
 			value = self.__sections[section][foundations.namespace.setNamespace(section, attribute)]
 		LOGGER.debug("> Attribute: '{0}', value: '{1}'.".format(attribute, value))
-		value = foundations.strings.encode(value) if encode else value
 		return value
 
 	def write(self,
@@ -861,9 +866,7 @@ class SectionsFileParser(foundations.io.File):
 			>>> sectionsFileParser.write()
 			True
 			>>> sectionsFileParser.read()
-			True
-			>>> print sectionsFileParser.content[0:5]
-			['[Section A]\\n', 'Attribute 1 = Value A\\n', '\\n', '[Section B]\\n', 'Attribute 2 = Value B\\n', '\\n']
+			u'[Section A]\\nAttribute 1 = Value A\\n\\n[Section B]\\nAttribute 2 = Value B\\n'
 
 		:param namespaces: Attributes are namespaced. ( Boolean )
 		:param splitter: Splitter character. ( String )
@@ -909,7 +912,7 @@ class SectionsFileParser(foundations.io.File):
 						LOGGER.debug("> Appending '{0}' comment with '{1}' value.".format(comment, value))
 						self.content.append(commentTemplate.format(value))
 			for attribute, value in self.__sections[section].iteritems():
-				if foundations.namespace.removeNamespace(attribute) == self.__rawSectionContentIdentifier:
+				if foundations.namespace.removeNamespace(attribute) == self.___raw__Identifier:
 					LOGGER.debug("> Appending '{0}' raw section content.".format(section))
 					for line in value:
 						self.content.append(line)
@@ -941,9 +944,9 @@ class PlistFileParser(foundations.io.File):
 			>>> plistFileParser.parse()
 			True
 			>>> plistFileParser.elements.keys()
-			['Dictionary A', 'Number A', 'Array A', 'String A', 'Date A', 'Boolean A', 'Data A']
+			[u'Dictionary A', u'Number A', u'Array A', u'String A', u'Date A', u'Boolean A', u'Data A']
 			>>> plistFileParser.elements["Dictionary A"]
-			{'String C': 'My Value C', 'String B': 'My Value B'}
+			{u'String C': u'My Value C', u'String B': u'My Value B'}
 
 		:param file: Current file path. ( String )
 		"""
@@ -958,9 +961,9 @@ class PlistFileParser(foundations.io.File):
 
 		self.__unserializers = {"array": lambda x: [value.text for value in x],
 								"dict": lambda x: dict((x[i].text, x[i + 1].text) for i in range(0, len(x), 2)),
-								"key": lambda x: x.text or unicode(),
-								"string": lambda x: x.text or unicode(),
-								"data": lambda x: base64.decodestring(x.text or unicode()),
+								"key": lambda x: foundations.strings.toString(x.text) or "",
+								"string": lambda x: foundations.strings.toString(x.text) or "",
+								"data": lambda x: base64.decodestring(x.text or ""),
 								"date": lambda x: datetime.datetime(*map(int, re.findall("\d+", x.text))),
 								"true": lambda x: True,
 								"false": lambda x: False,
@@ -1086,7 +1089,7 @@ class PlistFileParser(foundations.io.File):
 			>>> plistFileParser.parse()
 			True
 			>>> plistFileParser.elements.keys()
-			['Dictionary A', 'Number A', 'Array A', 'String A', 'Date A', 'Boolean A', 'Data A']
+			[u'Dictionary A', u'Number A', u'Array A', u'String A', u'Date A', u'Boolean A', u'Data A']
 
 		:param raiseParsingErrors: Raise parsing errors. ( Boolean )
 		:return: Method success. ( Boolean )
@@ -1157,9 +1160,9 @@ class PlistFileParser(foundations.io.File):
 			>>> plistFileParser.parse()
 			True
 			>>> plistFileParser.filterValues(r"String A")
-			['My Value A']
+			[u'My Value A']
 			>>> plistFileParser.filterValues(r"String.*")
-			['My Value C', 'My Value B', 'My Value A']
+			[u'My Value C', u'My Value B', u'My Value A']
 
 		:param pattern: Regex filtering pattern. ( String )
 		:param flags: Regex flags. ( Integer )
@@ -1187,7 +1190,7 @@ class PlistFileParser(foundations.io.File):
 			>>> plistFileParser.parse()
 			True
 			>>> plistFileParser.getValue("String A")
-			'My Value A'
+			u'My Value A'
 
 		:param element: Element to get the value. ( String )
 		:return: Element value. ( Object )
@@ -1208,15 +1211,15 @@ def getAttributeCompound(attribute, value=None, splitter="|", bindingIdentifier=
 		>>> data = "@Link | Value | Boolean | Link Parameter"
 		>>> attributeCompound = foundations.parsers.getAttributeCompound("Attribute Compound", data)
 		>>> attributeCompound.name
-		Attribute Compound
+		u'Attribute Compound'
 		>>> attributeCompound.value
-		Value
+		u'Value'
 		>>> attributeCompound.link
-		@Link
+		u'@Link'
 		>>> attributeCompound.type
-		Boolean
+		u'Boolean'
 		>>> attributeCompound.alias
-		Link Parameter
+		u'Link Parameter'
 		
 	:param attribute: Attribute. ( String )
 	:param value: Attribute value. ( Object )
@@ -1227,7 +1230,7 @@ def getAttributeCompound(attribute, value=None, splitter="|", bindingIdentifier=
 
 	LOGGER.debug("> Attribute: '{0}', value: '{1}'.".format(attribute, value))
 
-	if type(value) in (str, unicode):
+	if type(value) is unicode:
 		if splitter in value:
 			valueTokens = value.split(splitter)
 			if len(valueTokens) >= 3 and re.search(r"{0}\w*".format(bindingIdentifier), valueTokens[0]):
