@@ -14,6 +14,11 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
@@ -42,7 +47,7 @@ __status__ = "Production"
 
 __all__ = ["LOGGER",
 			"ASCII_CHARACTERS",
-			"encode",
+			"toString",
 			"getNiceName",
 			"getVersionRank",
 			"getSplitextBasename",
@@ -51,6 +56,7 @@ __all__ = ["LOGGER",
 			"getWords",
 			"filterWords",
 			"replace",
+			"removeStrip",
 			"toForwardSlashes",
 			"toBackwardSlashes",
 			"toPosixPath",
@@ -66,30 +72,30 @@ ASCII_CHARACTERS = "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ01234567
 #**********************************************************************************************************************
 #***	Module classes and definitions.
 #**********************************************************************************************************************
-def encode(data):
+def toString(data, encoding=Constants.encodingCodec, errors=Constants.encodingError):
 	"""
-	This definition encodes given data to unicode using package default settings.
+	This definition converts given data to unicode string using package default settings.
 
 	Usage::
 
-		>>> encode("myData")
+		>>> toString("myData")
 		u'myData'
-		>>> encode("汉字/漢字")
+		>>> toString("汉字/漢字")
 		u'\u6c49\u5b57/\u6f22\u5b57'
 
-	:param data: Data to encode. ( String )
-	:return: Encoded data. ( Unicode )
+	:param data: Data to convert. ( Object )
+	:param encoding: File encoding codec. ( String )
+	:param errors: File encoding errors handling. ( String )
+	:return: Unicode data. ( String )
 	"""
 
-	encodedData = None
-	if isinstance(data, unicode):
-		encodedData = data
+	if isinstance(data, type("")):
+		return data
 	else:
 		try:
-			encodedData = unicode(data, Constants.encodingFormat, Constants.encodingError)
+			return unicode(data, encoding, errors)
 		except TypeError:
-			encodedData = unicode(data.__str__(), Constants.encodingFormat, Constants.encodingError)
-	return encodedData
+			return unicode(str(data), encoding, errors)
 
 def getNiceName(name):
 	"""
@@ -98,9 +104,9 @@ def getNiceName(name):
 	Usage::
 
 		>>> getNiceName("getMeANiceName")
-		'Get Me A Nice Name'
+		u'Get Me A Nice Name'
 		>>> getNiceName("__getMeANiceName")
-		'__Get Me A Nice Name'
+		u'__Get Me A Nice Name'
 
 	:param name: Current string to be nicified. ( String )
 	:return: Nicified string. ( String )
@@ -138,7 +144,7 @@ def getSplitextBasename(path):
 	Usage::
 
 		>>> getSplitextBasename("/Users/JohnDoe/Documents/Test.txt")
-		'Test'
+		u'Test'
 
 	:param path: Path to extract the basename without extension. ( String )
 	:return: Splitext basename. ( String )
@@ -155,9 +161,9 @@ def getCommonAncestor(*args):
 	Usage::
 
 		>>> getCommonAncestor(("1", "2", "3"), ("1", "2", "0"), ("1", "2", "3", "4"))
-		('1', '2')
+		(u'1', u'2')
 		>>> getCommonAncestor("azerty", "azetty", "azello")
-		'aze'
+		u'aze'
 
 	:param \*args: Iterables to retrieve common ancestor from. ( Iterables )
 	:return: Common ancestor. ( Iterable )
@@ -179,7 +185,7 @@ def getCommonPathsAncestor(*args):
 	Usage::
 
 		>>> getCommonPathsAncestor("/Users/JohnDoe/Documents", "/Users/JohnDoe/Documents/Test.txt")
-		'/Users/JohnDoe/Documents'
+		u'/Users/JohnDoe/Documents'
 
 	:param \*args: Paths to retrieve common ancestor from. ( Strings )
 	:return: Common path ancestor. ( String )
@@ -196,7 +202,7 @@ def getWords(data):
 	Usage::
 
 		>>> getWords("Users are: John Doe, Jane Doe, Z6PO.")
-		['Users', 'are', 'John', 'Doe', 'Jane', 'Doe', 'Z6PO']
+		[u'Users', u'are', u'John', u'Doe', u'Jane', u'Doe', u'Z6PO']
 
 	:param data: Data to extract words from. ( String )
 	:return: Words. ( List )
@@ -213,11 +219,11 @@ def filterWords(words, filtersIn=None, filtersOut=None, flags=0):
 	Usage::
 
 		>>> filterWords(["Users", "are", "John", "Doe", "Jane", "Doe", "Z6PO"], filtersIn=("John", "Doe"))
-		['John', 'Doe', 'Doe']
+		[u'John', u'Doe', u'Doe']
 		>>> filterWords(["Users", "are", "John", "Doe", "Jane", "Doe", "Z6PO"], filtersIn=("\w*r",))
-		['Users', 'are']
+		[u'Users', u'are']
 		>>> filterWords(["Users", "are", "John", "Doe", "Jane", "Doe", "Z6PO"], filtersOut=("\w*o",))
-		['Users', 'are', 'Jane', 'Z6PO']
+		[u'Users', u'are', u'Jane', u'Z6PO']
 
 	:param filtersIn: Regex filters in list. ( Tuple / List )
 	:param filtersIn: Regex filters out list. ( Tuple / List )
@@ -259,7 +265,7 @@ def replace(string, data):
 
 		>>> replace("Users are: John Doe, Jane Doe, Z6PO.", {"John" : "Luke", "Jane" : "Anakin", "Doe" : "Skywalker",
 		 "Z6PO" : "R2D2"})
-		'Users are: Luke Skywalker, Anakin Skywalker, R2D2.'
+		u'Users are: Luke Skywalker, Anakin Skywalker, R2D2.'
 
 	:param string: String to manipulate. ( String )
 	:param data: Replacement occurences. ( Dictionary )
@@ -276,8 +282,8 @@ def removeStrip(string, pattern):
 
 	Usage::
 
-		>>> replaceStrip("John Doe", "John")
-		'Doe'
+		>>> removeStrip("John Doe", "John")
+		u'Doe'
 
 	:param string: String to manipulate. ( String )
 	:param pattern: Replacement pattern. ( String )
@@ -293,7 +299,7 @@ def toForwardSlashes(data):
 	Usage::
 
 		>>> toForwardSlashes("To\Forward\Slashes")
-		'To/Forward/Slashes'
+		u'To/Forward/Slashes'
 
 	:param data: Data to convert. ( String )
 	:return: Converted path. ( String )
@@ -310,7 +316,7 @@ def toBackwardSlashes(data):
 	Usage::
 
 		>>> toBackwardSlashes("/Users/JohnDoe/Documents")
-		'\\Users\\JohnDoe\\Documents'
+		u'\\Users\\JohnDoe\\Documents'
 
 	:param data: Data to convert. ( String )
 	:return: Converted path. ( String )
@@ -327,7 +333,7 @@ def toPosixPath(path):
 	Usage::
 
 		>>> toPosixPath("c:\\Users\\JohnDoe\\Documents")
-		'/Users/JohnDoe/Documents'
+		u'/Users/JohnDoe/Documents'
 
 	:param path: Windows path. ( String )
 	:return: Path converted to Posix path. ( String )
@@ -343,8 +349,8 @@ def getNormalizedPath(path):
 
 	Usage::
 
-		>>> getNormalizedPath("C:\Users\JohnDoe\Documents")
-		'C:\\Users\\JohnDoe\\Documents'
+		>>> getNormalizedPath("C:\\Users/johnDoe\\Documents")
+		u'C:\\Users\\JohnDoe\\Documents'
 
 	:param path: Path to normalize. ( String )
 	:return: Normalized path. ( String )
@@ -366,13 +372,13 @@ def getRandomSequence(length=8):
 	Usage::
 
 		>>> getRandomSequence()
-		arGAqzf3
+		u'N_mYO7g5'
 
 	:param length: Length of the sequence. ( Integer )
 	:return: Random sequence. ( String )
 	"""
 
-	return str().join([random.choice(ASCII_CHARACTERS) for i in range(length)])
+	return "".join([random.choice(ASCII_CHARACTERS) for i in range(length)])
 
 def isEmail(data):
 	"""
