@@ -13,14 +13,33 @@
 **Others:**
 
 """
+
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
+#**********************************************************************************************************************
+#***	Encoding manipulations.
+#**********************************************************************************************************************
+import sys
+
+def _setEncoding():
+	"""
+	This definition sets the Application encoding.
+	"""
+
+	reload(sys)
+	sys.setdefaultencoding("utf-8")
+
+_setEncoding()
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
 import glob
-import logging
 import os
 import re
-import sys
 if sys.version_info[:2] <= (2, 6):
 	from ordereddict import OrderedDict
 else:
@@ -29,35 +48,27 @@ else:
 #**********************************************************************************************************************
 #***	Internal imports.
 #**********************************************************************************************************************
-import foundations.core as core
-import foundations.strings as strings
+import foundations.strings
+import foundations.verbose
 from foundations.io import File
-from foundations.globals.constants import Constants
 
 #**********************************************************************************************************************
 #***	Module attributes.
 #**********************************************************************************************************************
 __author__ = "Thomas Mansencal"
-__copyright__ = "Copyright (C) 2008 - 2012 - Thomas Mansencal"
+__copyright__ = "Copyright (C) 2008 - 2013 - Thomas Mansencal"
 __license__ = "GPL V3.0 - http://www.gnu.org/licenses/"
 __maintainer__ = "Thomas Mansencal"
 __email__ = "thomas.mansencal@gmail.com"
 __status__ = "Production"
 
 __all__ = ["LOGGER",
-		"LOGGING_CONSOLE_HANDLER",
 		"FILES_EXTENSION",
 		"TOCTREE_TEMPLATE_BEGIN",
 		"TOCTREE_TEMPLATE_END",
 		"getSphinxDocumentationTocTree"]
 
-LOGGER = logging.getLogger(Constants.logger)
-
-LOGGING_CONSOLE_HANDLER = logging.StreamHandler(sys.stdout)
-LOGGING_CONSOLE_HANDLER.setFormatter(core.LOGGING_DEFAULT_FORMATTER)
-LOGGER.addHandler(LOGGING_CONSOLE_HANDLER)
-
-core.setVerbosityLevel(3)
+LOGGER = foundations.verbose.installLogger()
 
 FILES_EXTENSION = ".rst"
 
@@ -76,6 +87,9 @@ TOCTREE_TEMPLATE_END = ["Search:\n",
 					"* :ref:`modindex`\n",
 					"* :ref:`search`\n", ]
 
+foundations.verbose.getLoggingConsoleHandler()
+foundations.verbose.setVerbosityLevel(3)
+
 #**********************************************************************************************************************
 #***	Module classes and definitions.
 #**********************************************************************************************************************
@@ -92,9 +106,9 @@ def getSphinxDocumentationTocTree(title, fileIn, fileOut, contentDirectory):
 	LOGGER.info("{0} | Building Sphinx documentation index '{1}' file!".format(getSphinxDocumentationTocTree.__name__,
 																				fileOut))
 	file = File(fileIn)
-	file.read()
+	file.cache()
 
-	existingFiles = [strings.getSplitextBasename(item)
+	existingFiles = [foundations.strings.getSplitextBasename(item)
 					for item in glob.glob("{0}/*{1}".format(contentDirectory, FILES_EXTENSION))]
 	relativeDirectory = contentDirectory.replace("{0}/".format(os.path.dirname(fileOut)), "")
 
@@ -125,4 +139,5 @@ def getSphinxDocumentationTocTree(title, fileIn, fileOut, contentDirectory):
 	file.write()
 
 if __name__ == "__main__":
-	getSphinxDocumentationTocTree(sys.argv[1], sys.argv[2], sys.argv[3], sys.argv[4])
+	arguments = map(unicode, sys.argv)
+	getSphinxDocumentationTocTree(arguments[1], arguments[2], arguments[3], arguments[4])
