@@ -14,12 +14,31 @@
 
 """
 
+#**********************************************************************************************************************
+#***	Future imports.
+#**********************************************************************************************************************
+from __future__ import unicode_literals
+
+#**********************************************************************************************************************
+#***	Encoding manipulations.
+#**********************************************************************************************************************
+import sys
+
+def _setEncoding():
+	"""
+	This definition sets the Application encoding.
+	"""
+
+	reload(sys)
+	sys.setdefaultencoding("utf-8")
+
+_setEncoding()
+
 #**********************************************************************************************************************
 #***	External imports.
 #**********************************************************************************************************************
 import os
 import re
-import sys
 if sys.version_info[:2] <= (2, 6):
 	from ordereddict import OrderedDict
 else:
@@ -116,4 +135,5 @@ def sliceDocumentation(fileIn, outputDirectory):
 		index += 1
 
 if __name__ == "__main__":
-	sliceDocumentation(sys.argv[1], sys.argv[2])
+	arguments = map(unicode, sys.argv)
+	sliceDocumentation(arguments[1], arguments[2])
